@@ -8,7 +8,7 @@ use IO::Async::Loop;
 use IO::Async::Stream;
 use IO::Pty 1.12;
 use Tickit::Async;
-use Tickit::Widgets qw( Border VTerm );
+use Tickit::Widgets qw( Border Term );
 
 my $loop = IO::Async::Loop->new;
 
@@ -17,7 +17,7 @@ my $t = Tickit::Async->new(
       h_border => 4,
       v_border => 2,
       bg => ( 1 + int rand 6 ),
-   )->set_child( my $widget = Tickit::Widget::VTerm->new( bg => 0 ) )
+   )->set_child( my $widget = Tickit::Widget::Term->new( bg => 0 ) )
 );
 $loop->add( $t );
 
@@ -28,33 +28,12 @@ begin_shell( $loop );
 $t->run;
 
 my $_pty;
-my $_stream;
 
 sub begin_shell ( $loop )
 {
    $_pty = IO::Pty->new;
-   $loop->add( $_stream = IO::Async::Stream->new(
-      handle => $_pty,
-      on_read => sub {
-         my ( undef, $buffref ) = @_;
 
-         my $writtenlen = $widget->write_input( $$buffref );
-
-         substr( $$buffref, 0, $writtenlen, "" );
-
-         $widget->flush;
-
-         return 0;
-      }
-   ) );
-
-   $widget->set_on_output( sub ( $buf ) {
-      $_stream->write( $buf );
-   });
-
-   $widget->set_on_resize( sub ( $lines, $cols ) {
-      $_pty->set_winsize( $lines, $cols );
-   });
+   $widget->use_pty( $_pty );
 
    my $slave = $_pty->slave;
    $loop->open_child(
